BoundTexture

Struct BoundTexture 

pub struct BoundTexture<'a, B, D, P>
where B: PipelineTexture<D, P>, D: Dimensionable, P: Pixel,
{ /* private fields */ }
A bound Texture.

Parametricity

Notes

Once a Texture is bound, it can be used and passed around to shaders. In order to do so, you will need to pass a TextureBinding to your ProgramInterface. That value is unique to each BoundTexture and should always be asked — you shouldn’t cache them, for instance.

Getting a TextureBinding is a cheap operation and is performed via the BoundTexture::binding method.

Implementations

Source

impl<'a, B, D, P> BoundTexture<'a, B, D, P>
where B: PipelineTexture<D, P>, D: Dimensionable, P: Pixel,

pub fn binding(&self) -> TextureBinding<D, P::SamplerType>

Obtain a TextureBinding object that can be used to refer to this bound texture in shader stages.

Notes

You shouldn’t try to do store / cache or do anything special with that value. Consider it an opaque object.