pub struct Program<B, Sem, Out, Uni>where
B: Shader,{ /* private fields */ }Expand description
A shader program.
Shader programs are GPU binaries that execute when a draw command is issued.
Parametricity
Bis the backend type.Semis theSemanticstype.Outis the render target type.Uniis theUniformInterfacetype.
Implementations
Sourceimpl<B, Sem, Out, Uni> Program<B, Sem, Out, Uni>
impl<B, Sem, Out, Uni> Program<B, Sem, Out, Uni>
Sourcepub fn adapt<Q>(
self,
) -> Result<BuiltProgram<B, Sem, Out, Q>, AdaptationFailure<B, Sem, Out, Uni>>where
Q: UniformInterface<B>,
pub fn adapt<Q>(
self,
) -> Result<BuiltProgram<B, Sem, Out, Q>, AdaptationFailure<B, Sem, Out, Uni>>where
Q: UniformInterface<B>,
Create a new UniformInterface but keep the Program around without rebuilding it.
Parametricity
Qis the newUniformInterface.
Sourcepub fn adapt_env<Q, E>(
self,
env: &mut E,
) -> Result<BuiltProgram<B, Sem, Out, Q>, AdaptationFailure<B, Sem, Out, Uni>>where
Q: UniformInterface<B, E>,
pub fn adapt_env<Q, E>(
self,
env: &mut E,
) -> Result<BuiltProgram<B, Sem, Out, Q>, AdaptationFailure<B, Sem, Out, Uni>>where
Q: UniformInterface<B, E>,
Create a new UniformInterface but keep the Program around without rebuilding it, by
using a mutable environment variable.
Parametricity
Qis the newUniformInterface.Eis the mutable environment variable.
Sourcepub fn readapt_env<E>(
self,
env: &mut E,
) -> Result<BuiltProgram<B, Sem, Out, Uni>, AdaptationFailure<B, Sem, Out, Uni>>where
Uni: UniformInterface<B, E>,
pub fn readapt_env<E>(
self,
env: &mut E,
) -> Result<BuiltProgram<B, Sem, Out, Uni>, AdaptationFailure<B, Sem, Out, Uni>>where
Uni: UniformInterface<B, E>,
Re-create the UniformInterface but keep the Program around without rebuilding it.
Parametricity
Eis the mutable environment variable.