ProgramInterface

Struct ProgramInterface 

pub struct ProgramInterface<'a, B>
where B: Shader,
{ /* private fields */ }
Interact with the UniformInterface carried by a Program and/or perform dynamic uniform lookup.

This type allows to set — ProgramInterface::set – uniforms for a Program.

In the case where you don’t have a uniform interface or need to dynamically lookup uniforms, you can use the ProgramInterface::query method.

Parametricity

B is the backend type.

Implementations

Source

impl<'a, B> ProgramInterface<'a, B>
where B: Shader,

pub fn set<'u, T>(&'u mut self, uniform: &'u Uniform<T>, value: B::Target)
where B: Uniformable<'u, T>,

Set a value on a Uniform.

The value that is passed depends on the associated Uniformable::Target type. Most of the time, it will be the same as T, but it might sometimes be something different if you are using existential types, such as with types with lifetimes.

pub fn query(&mut self) -> Result<UniformBuilder<'a, B>, ProgramError>

Get back a UniformBuilder to dynamically access Uniform objects.